@@ -226,7 +226,7 @@ static int
    bool opt_ver = true;	/* verify peer certificate */
    char *opt_cert = NULL;	/* file name of client certificate */
    const char *opt_commonname = NULL;	/* for checking peer certificate */
-   bool        opt_no_sni;
+   bool        opt_no_sni = false;
    const char *opt_snihost = NULL;	/* for SNI host */
    int result;
 
@@ -1539,7 +1539,7 @@ static int openssl_setenv_cert_name(const char *field, X509_NAME *name) {
    }
    memcpy(str, buf, len);
    str[len] = '\0';
-   Info2("SSL peer cert %s: \"%s\"", field, buf);
+   Info2("SSL peer cert %s: \"%s\"", field, str);
    xiosetenv2("OPENSSL_X509", field, str, 1, NULL);
    free(str);
    BIO_free(bio);
